# -*- mode: python ; coding: utf-8 -*-
import tkinter as tk
import random
import threading
import time


def boom():
    window = tk.Tk()
    width = window.winfo_screenwidth()
    height = window.winfo_screenheight()
    a = random.randrange(0, width)
    b = random.randrange(0, height)
    window.title('HELLO，牛逼')
    window.geometry("200x50" + "+" + str(a) + "+" + str(b))
    tk.Label(window, text='HELLO,牛逼', bg='green',
             font=('宋体', 17), width=20, height=4).pack()
    window.mainloop()


threads = []
for i in range(100):
    t = threading.Thread(target=boom)
    threads.append(t)
    time.sleep(0.1)
    threads[i].start()

if __name__ == '__main__':
    boom()


from setuptools import setup, find_packages
setup(
    name="chenyutong",
    version="0.0.1",
    author="chenyutong",
    author_email="2463400852@qq.com",
    description="This is me xiajibaxiede",

    url="https://github.com/sunjian-github/ezface",

    packages=find_packages()
)